@@ -2,12 +2,23 @@ import base64
 import uuid
 from time import time
 
+from Crypto.Hash import SHA1
 from Crypto.PublicKey import RSA
 from Crypto.Cipher import PKCS1_OAEP
+from Crypto.Signature import PKCS1_v1_5
 
 
 class Client:
 
+    @staticmethod
+    def sha1Sign(message: bytes, private_key: str) -> bytes:
+        private_key = RSA.import_key(private_key)
+        signer = PKCS1_v1_5.new(private_key)
+        digest = SHA1.new(message)
+        sign = signer.sign(digest)
+
+        return sign
+
     @staticmethod
     def encrypt(public_key: str, data: bytes) -> bytes:
         """
